@@ -11,12 +11,12 @@ from .baserule import BaseRule
 from . import Rule
 
 
-class Fields(BaseRule):
+class DomainEmulFields(BaseRule):
     domain_part: str  # "com"
 
 
 class DomainEmulRule(Rule):
-    fields: Type[BaseModel] = Fields
+    fields: Type[BaseModel] = DomainEmulFields
 
     @property
     def calc_weight(self):
