@@ -11,12 +11,12 @@ from .baserule import BaseRule
 from . import Rule
 
 
-class Fields(BaseRule):
+class GreenDomainFields(BaseRule):
     domain_name: str
 
 
 class GreenDomainRule(Rule):
-    fields: Type[BaseModel] = Fields
+    fields: Type[BaseModel] = GreenDomainFields
 
     @property
     def calc_weight(self):
