@@ -16,7 +16,7 @@ from .baserule import BaseRule
 from . import Rule
 
 
-class Fields(BaseRule):
+class NumbersFields(BaseRule):
     keyword: str
     min_numbers_qty: int
     max_numbers_qty: int
@@ -26,7 +26,7 @@ class Fields(BaseRule):
 
 
 class NumbersRule(Rule):
-    fields: Type[BaseModel] = Fields
+    fields: Type[BaseModel] = NumbersFields
 
     def set_rules(self, **kwargs):
         super().set_rules(**kwargs)
