@@ -7,12 +7,12 @@ from .baserule import BaseRule
 from . import Rule
 
 
-class Fields(BaseRule):
+class RedDomainFields(BaseRule):
     domain_name: str
 
 
 class RedDomainRule(Rule):
-    fields = Fields
+    fields = RedDomainFields
 
     @property
     def calc_weight(self):
