@@ -4,12 +4,12 @@ from .baserule import BaseRule
 from . import Rule
 
 
-class Fileds(BaseRule):
+class SubDomainFields(BaseRule):
     min_qty: int
 
 
 class SubdomainRule(Rule):
-    fields: Type[BaseRule] = Fileds
+    fields: Type[BaseRule] = SubDomainFields
 
     @property
     def calc_weight(self):
