@@ -4,14 +4,14 @@ from .baserule import BaseRule
 from . import Rule
 
 
-class Fields(BaseRule):
+class SubstringFields(BaseRule):
     subwords: List[str]
 
 
 class SubstringRule(Rule):
     """Правило"""
 
-    fields: Type[BaseRule] = Fields
+    fields: Type[BaseRule] = SubstringFields
 
     @property
     def calc_weight(self):
