@@ -4,13 +4,13 @@ from .baserule import BaseRule
 from . import Rule
 
 
-class Fileds(BaseRule):
+class SymbolFileds(BaseRule):
     symbol: str
     min_qty: int
 
 
 class SymbolRule(Rule):
-    fields: Type[BaseRule] = Fileds
+    fields: Type[BaseRule] = SymbolFileds
 
     @property
     def calc_weight(self):
